%{?mingw_package_header}

## NOTE: Lots of files in various subdirectories have the same name (such as
## "LICENSE") so this short macro allows us to distinguish them by using their
## directory names (from the source tree) as prefixes for the files.
%global add_to_doc_files32() \
    mkdir -p %{buildroot}%{_docdir}/mingw32-webkitgtk3-%{version} ||: ; \
    cp -p %1  %{buildroot}%{_docdir}/mingw32-webkitgtk3-%{version}/$(echo '%1' | sed -e 's!/!.!g')
%global add_to_doc_files64() \
    mkdir -p %{buildroot}%{_docdir}/mingw64-webkitgtk3-%{version} ||: ; \
    cp -p %1  %{buildroot}%{_docdir}/mingw64-webkitgtk3-%{version}/$(echo '%1' | sed -e 's!/!.!g')

Name:           mingw-webkitgtk3
Version:        1.8.3
Release:        1%{?dist}
Summary:        MinGW Windows GTK+ Web content engine library

Group:          Development/Libraries
License:        LGPLv2+ and BSD
URL:            http://webkit.org/

Source0:        http://webkitgtk.org/releases/webkit-%{version}.tar.xz

# Skip building the DumpRenderTree tool which requires internal symbols that
# aren't exported in the .dll.
Patch2:         webkit-dont-build-dump-render-tree.patch

# Fix the build with spellchecking enabled
# https://bugs.webkit.org/show_bug.cgi?id=93255
Patch3:         webkit-fix-spellcheck-build.patch

BuildArch:      noarch

BuildRequires:  bison
BuildRequires:  flex
BuildRequires:  gettext
BuildRequires:  gperf

# For autoreconf
BuildRequires:  autoconf automake libtool
BuildRequires:  gtk-doc

# Required for glib-mkenums
BuildRequires:  glib2-devel

BuildRequires:  mingw32-binutils
BuildRequires:  mingw32-enchant
BuildRequires:  mingw32-filesystem >= 95
BuildRequires:  mingw32-fontconfig
BuildRequires:  mingw32-freetype
BuildRequires:  mingw32-gcc
BuildRequires:  mingw32-gcc-c++
BuildRequires:  mingw32-gstreamer
BuildRequires:  mingw32-gstreamer-plugins-base
BuildRequires:  mingw32-gtk3
BuildRequires:  mingw32-icu
BuildRequires:  mingw32-libidn
BuildRequires:  mingw32-libsoup
BuildRequires:  mingw32-libxml2
BuildRequires:  mingw32-libxslt
BuildRequires:  mingw32-pthreads
BuildRequires:  mingw32-sqlite

BuildRequires:  mingw64-binutils
BuildRequires:  mingw64-enchant
BuildRequires:  mingw64-filesystem >= 95
BuildRequires:  mingw64-fontconfig
BuildRequires:  mingw64-freetype
BuildRequires:  mingw64-gcc
BuildRequires:  mingw64-gcc-c++
BuildRequires:  mingw64-gstreamer
BuildRequires:  mingw64-gstreamer-plugins-base
BuildRequires:  mingw64-gtk3
BuildRequires:  mingw64-icu
BuildRequires:  mingw64-libidn
BuildRequires:  mingw64-libsoup
BuildRequires:  mingw64-libxml2
BuildRequires:  mingw64-libxslt
BuildRequires:  mingw64-pthreads
BuildRequires:  mingw64-sqlite


%description
WebKitGTK+ is an open-source Web content engine library.
This package contains the shared libraries for the WebKit GTK+ port
as well as the sample GtkLauncher tool.

This is the MinGW port of WebKitGTK+ for GTK+ 3.


%package -n mingw32-webkitgtk3
Summary:        MinGW Windows web content engine library

%description -n mingw32-webkitgtk3
WebKitGTK+ is an open-source Web content engine library.
This package contains the shared libraries for the WebKit GTK+ port
as well as the sample GtkLauncher tool.

This is the MinGW port of WebKitGTK+ for GTK+ 3.


%package -n mingw64-webkitgtk3
Summary:        MinGW Windows web content engine library

%description -n mingw64-webkitgtk3
WebKitGTK+ is an open-source Web content engine library.
This package contains the shared libraries for the WebKit GTK+ port
as well as the sample GtkLauncher tool.

This is the MinGW port of WebKitGTK+ for GTK+ 3.


%{?mingw_debug_package}


%prep
%setup -qn "webkit-%{version}"

%patch2 -p0 -b .dumprendertree
%patch3 -p1 -b .spellcheck
autoreconf --verbose --install -I Source/autotools


%build
# lower debug level to prevent memory exhaustion by linker
%global mingw32_cflags %(echo %{mingw32_cflags} | sed 's/-g /-g1 /')
%global mingw64_cflags %(echo %{mingw64_cflags} | sed 's/-g /-g1 /')

%mingw_configure                                                \
                        --with-target=win32                     \
                        --with-gtk=3.0                          \
                        --with-font-backend=freetype            \
                        --with-unicode-backend=icu              \
                        --disable-geolocation                   \
                        --disable-gtk-doc-html

# %%{?_smp_mflags} disabled to avoid parallel make issues
%mingw_make V=1


%install
%mingw_make install DESTDIR=%{buildroot}

install -m 755 build_win32/Programs/.libs/GtkLauncher.exe %{buildroot}%{mingw32_bindir}/GtkLauncher-3.exe
install -m 755 build_win64/Programs/.libs/GtkLauncher.exe %{buildroot}%{mingw64_bindir}/GtkLauncher-3.exe

# Drop all .la files
find $RPM_BUILD_ROOT -name "*.la" -delete

%mingw_find_lang webkit-3.0

## Copy over and rename the various files for %%doc inclusion.
%add_to_doc_files32 Source/WebKit/LICENSE
%add_to_doc_files32 Source/WebKit/gtk/po/README
%add_to_doc_files32 Source/WebKit/gtk/NEWS
%add_to_doc_files32 Source/WebCore/icu/LICENSE
%add_to_doc_files32 Source/WebCore/LICENSE-APPLE
%add_to_doc_files32 Source/WebCore/LICENSE-LGPL-2
%add_to_doc_files32 Source/WebCore/LICENSE-LGPL-2.1
%add_to_doc_files32 Source/JavaScriptCore/COPYING.LIB
%add_to_doc_files32 Source/JavaScriptCore/THANKS
%add_to_doc_files32 Source/JavaScriptCore/AUTHORS
%add_to_doc_files32 Source/JavaScriptCore/icu/README
%add_to_doc_files32 Source/JavaScriptCore/icu/LICENSE

%add_to_doc_files64 Source/WebKit/LICENSE
%add_to_doc_files64 Source/WebKit/gtk/po/README
%add_to_doc_files64 Source/WebKit/gtk/NEWS
%add_to_doc_files64 Source/WebCore/icu/LICENSE
%add_to_doc_files64 Source/WebCore/LICENSE-APPLE
%add_to_doc_files64 Source/WebCore/LICENSE-LGPL-2
%add_to_doc_files64 Source/WebCore/LICENSE-LGPL-2.1
%add_to_doc_files64 Source/JavaScriptCore/COPYING.LIB
%add_to_doc_files64 Source/JavaScriptCore/THANKS
%add_to_doc_files64 Source/JavaScriptCore/AUTHORS
%add_to_doc_files64 Source/JavaScriptCore/icu/README
%add_to_doc_files64 Source/JavaScriptCore/icu/LICENSE


%files -n mingw32-webkitgtk3 -f mingw32-webkit-3.0.lang
%{_docdir}/mingw32-webkitgtk3-%{version}/
%{mingw32_bindir}/jsc-3.exe
%{mingw32_bindir}/GtkLauncher-3.exe
%{mingw32_bindir}/libjavascriptcoregtk-3.0-0.dll
%{mingw32_bindir}/libwebkitgtk-3.0-0.dll
%{mingw32_includedir}/webkitgtk-3.0/
%{mingw32_libdir}/libjavascriptcoregtk-3.0.dll.a
%{mingw32_libdir}/libwebkitgtk-3.0.dll.a
%{mingw32_libdir}/pkgconfig/javascriptcoregtk-3.0.pc
%{mingw32_libdir}/pkgconfig/webkitgtk-3.0.pc
%{mingw32_datadir}/webkitgtk-3.0/

%files -n mingw64-webkitgtk3 -f mingw64-webkit-3.0.lang
%{_docdir}/mingw64-webkitgtk3-%{version}/
%{mingw64_bindir}/jsc-3.exe
%{mingw64_bindir}/GtkLauncher-3.exe
%{mingw64_bindir}/libjavascriptcoregtk-3.0-0.dll
%{mingw64_bindir}/libwebkitgtk-3.0-0.dll
%{mingw64_includedir}/webkitgtk-3.0/
%{mingw64_libdir}/libjavascriptcoregtk-3.0.dll.a
%{mingw64_libdir}/libwebkitgtk-3.0.dll.a
%{mingw64_libdir}/pkgconfig/javascriptcoregtk-3.0.pc
%{mingw64_libdir}/pkgconfig/webkitgtk-3.0.pc
%{mingw64_datadir}/webkitgtk-3.0/


%changelog
* Thu Aug 30 2012 Kalev Lember <kalevlember@gmail.com> - 1.8.3-1
- Update to 1.8.3

* Mon Aug 06 2012 Kalev Lember <kalevlember@gmail.com> - 1.8.2-1
- Update to 1.8.2
- Backport NPAPI plugin support from trunk
- Fix the build with spellchecking enabled (Paweł Forysiuk)

* Wed Jun 13 2012 Kalev Lember <kalevlember@gmail.com> - 1.8.1-1
- Initial mingw-webkitgtk3 packaging, based on Fedora mingw-webkitgtk
